package com.bipt.intelligentapplicationorchestrationservice.util;

import com.alibaba.nacos.api.naming.NamingFactory;
import com.alibaba.nacos.api.naming.NamingService;
import com.alibaba.nacos.api.naming.pojo.Instance;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Component
public class NacosServiceUtil {

    @Value("${spring.cloud.nacos.discovery.server-addr}")
    private String nacosServerAddr;

    public void registerService(String serviceName, String ip, int port, String url) throws Exception { // 新增url参数
        NamingService naming = NamingFactory.createNamingService(nacosServerAddr);
        Instance instance = new Instance();
        instance.setIp(ip);
        instance.setPort(port);
        // 添加元数据存储URL
        Map<String, String> metadata = new HashMap<>();
        metadata.put("url", url); // 将URL存入元数据
        instance.setMetadata(metadata);
        naming.registerInstance(serviceName, instance);
    }

    /**
     * 获取服务所有实例IP
     */
    public List<String> getServiceInstances(String serviceName) throws Exception {
        NamingService naming = NamingFactory.createNamingService(nacosServerAddr);
        List<Instance> instances = naming.getAllInstances(serviceName);
        return instances.stream()
                .map(Instance::getIp)
                .collect(Collectors.toList());
    }
}